import hashlib


def generate_pseudonym(
    service_provider_salt: str, entry_uuid: str, school_authority: str
) -> str:
    h = hashlib.blake2b()
    h.update(service_provider_salt.encode() + b"\n")
    h.update(school_authority.encode() + b"\n")
    h.update(entry_uuid.encode())
    return h.hexdigest()
